#!/usr/bin/env python
"""Profiling for fractions.py

You can run it by
env PROFILER=profile python prof.py
This does all profiling by the older Python profiler

Alternatively, you can profile it with the newer HotShot,
which is much more accurate. To run this you need to type
env PROFILER=hotshot python prof.py

And you can run it just in timing mode... [write on about it]
"""
import sys, os, os.path
from test_fractions import *

proffile = 'unittest.profile'

def hack():
    import unitunlock
    unittest.main = unitunlock.main
    unittest.main()    
    print 'done'

def proper():
    try:
	unittest.main()
    except SystemExit:
	# catch the exiting, and deny it
        pass
    print 'done'

def hot():
    import hotshot
    import hotshot.stats
    
    profiler = hotshot.Profile(proffile)
    profiler.run('proper()')
    profiler.close()
    stats = hotshot.stats.load(proffile)
    stats.sort_stats("cumulative")
    stats.print_stats()

def clean():
    """Remove the profile-file"""
    if os.path.exists(proffile):
	os.remove(proffile)

def prof():
    import profile
    import pstats
    profiler = profile.run('proper()', proffile)
    stats = pstats.Stats(proffile)
    stats.sort_stats('cumulative')
    stats.print_stats()

def timings():
    import fractions
    import timeit
    s = """import fractions
f = fractions.Fraction('1/2')"""
    t = timeit.Timer(stmt=s)
    print "%.2f usec/pass" % (1000000 * t.timeit(number=100000)/100000)

if __name__ == '__main__':
    print 'prof.py - fractions.py performance tester'
    try:
	osprof = os.environ['PROFILER']
    except KeyError:
	print 'Use the environment variable PROFILER to use a profiler: profile or hotshot'
	osprof = None

    
    if osprof == 'hotshot':
	clean()
	hot()
	clean()
    elif osprof == 'profile':
	clean()
	prof()
	clean()
    elif osprof == None:
	clean()
	timings()